#[non_exhaustive]pub struct PacketMeta {
pub id: u32,
}Expand description
Metadata associated with a packet.
The packet metadata is a set of attributes associated to network packets
as they travel up or down the stack. The metadata is get/set by the
Driver implementations or by the user when sending/receiving packets
from a socket.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: u32An identifier associated with a transmitted or received packet.