Struct UdpMetadata
pub struct UdpMetadata {
pub endpoint: Endpoint,
pub local_address: Option<Address>,
pub meta: PacketMeta,
}Expand description
Metadata for a sent or received UDP datagram.
Fields
endpoint: EndpointThe remote endpoint: the sender of an incoming datagram, or the destination of an outgoing one.
local_address: Option<Address>The local address: the destination of an incoming datagram (always set), or the source of an outgoing one. If not set on an outgoing datagram (and the socket is not bound to a single address), a suitable source address is selected automatically.
meta: PacketMetaThe datagram’s packet metadata: what the driver attached to an incoming datagram, or what to attach to an outgoing one (an id to tag it with, a transmit timestamp to request).
Zero-sized unless a packetmeta-* feature is enabled.