embassy-net

Crates

git

Versions

default

Flavors

UdpMetadata

Struct UdpMetadata 

pub struct UdpMetadata {
    pub endpoint: IpEndpoint,
    pub local_address: Option<IpAddress>,
    pub meta: PacketMeta,
}
Metadata for a sent or received UDP packet.

Fields

endpoint: IpEndpoint

The IP endpoint from which an incoming datagram was received, or to which an outgoing datagram will be sent.

local_address: Option<IpAddress>

The IP address to which an incoming datagram was sent, or from which an outgoing datagram will be sent. Incoming datagrams always have this set. On outgoing datagrams, if it is not set, and the socket is not bound to a single address anyway, a suitable address will be determined using the algorithms of RFC 6724 (candidate source address selection) or some heuristic (for IPv4).

meta: PacketMeta

Additional metadata for the packet.